function [Amari_Index] = amari_metric(A_real, A_estim)

%function [Amari_Index] = amari_metric(A_real, A_estim)
%
% Amari index computation
% (not sensitive to permutations and normalisations)
% INPUTS :
%           A_real : real mixing matrix
%           A_estim : estimated mixing matrix
%
% OUTPUTS :
%           Amari_Index : Amari index (in [0,1])

pA_real = (A_real' * A_real) \ A_real';

G = pA_real * A_estim;
K = size(G,1); %G is a square matrix
Amari_Index =  1 / (2*K*(K - 1)) * sum((sum(abs(G), 2) ./ max(abs(G), [], 2)) - 1) ...
    + 1 / (2*K*(K - 1)) * sum((sum(abs(G), 1) ./ max(abs(G), [], 1)) - 1);
end
