function [A, S] = normalise(A,S,pdata)

% function [Ai, Si] = normalise(pdata)
%
% option de renormalisation des donnees
% la separation se faisant a une permutation pret et a un facteur de
% renormalisation pret, on peut choisir de normaliser les donnees au debut
% de l'algo et/ou a chaque iteration de l'algo et/ou a la fin de l'algo
% on peut normaliser les colonnes de A (attention, ce sont les lignes de A
% qui pourraient sommer  1) ou les lignes de S (chaque source)
%
% INPUTS :
%           A : matrice de melange a normaliser (Ai si a l'initialisation)
%           S : matrice de sources a normaliser (Si si a l'initialisation)
%           pdata : stucture contenant les donnees et les parametres de
%           normalisation
%
% OUTPUTS :
%           A : matrice de melange normalisee
%           S : matrice de sources normalisee

switch pdata.Norm.x
    case 'A'
        if pdata.Norm.dim~=1
            error('Attention vous ne normalisez pas les colonnes de A');
        end
        sumA=sum(abs(A).^pdata.Norm.p,pdata.Norm.dim);
        A=A./repmat(sumA.^(1/pdata.Norm.p),size(A,1),1);
        S=S.*repmat(sumA.^(1/pdata.Norm.p)',1,size(S,2));
    case 'S'
        if pdata.Norm.dim~=2
            error('Attention vous ne normalisez pas les lignes de S');
        end
        sumS=sum(abs(S).^pdata.Norm.p,pdata.Norm.dim);
        S=S./repmat(sumS.^(1/pdata.Norm.p),1,size(S,2));
        A=A.*repmat(sumS.^(1/pdata.Norm.p)',size(A,1),1);
    otherwise
        disp('Unknown normalisation type');
end